@@ -148,6 +148,7 @@ __all__ = (
     "SessionStateType",
     "SessionStatusType",
     "SignalTypeType",
+    "SourceTypeType",
     "StepExecutionFilterKeyType",
     "StopTypeType",
     "ServiceName",
@@ -468,7 +469,7 @@ PatchPropertyType = Literal[
 ]
 PatchSetType = Literal["APPLICATION", "OS"]
 PingStatusType = Literal["ConnectionLost", "Inactive", "Online"]
-PlatformTypeType = Literal["Linux", "Windows"]
+PlatformTypeType = Literal["Linux", "MacOS", "Windows"]
 RebootOptionType = Literal["NoReboot", "RebootIfNeeded"]
 ResourceDataSyncS3FormatType = Literal["JsonSerDe"]
 ResourceTypeForTaggingType = Literal[
@@ -490,6 +491,7 @@ SessionStatusType = Literal[
     "Connected", "Connecting", "Disconnected", "Failed", "Terminated", "Terminating"
 ]
 SignalTypeType = Literal["Approve", "Reject", "Resume", "StartStep", "StopStep"]
+SourceTypeType = Literal["AWS::EC2::Instance", "AWS::IoT::Thing", "AWS::SSM::ManagedInstance"]
 StepExecutionFilterKeyType = Literal[
     "Action",
     "StartTimeAfter",
@@ -603,6 +605,7 @@ ServiceName = Literal[
     "emr-containers",
     "es",
     "events",
+    "evidently",
     "finspace",
     "finspace-data",
     "firehose",
@@ -629,6 +632,7 @@ ServiceName = Literal[
     "imagebuilder",
     "importexport",
     "inspector",
+    "inspector2",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -687,6 +691,7 @@ ServiceName = Literal[
     "meteringmarketplace",
     "mgh",
     "mgn",
+    "migration-hub-refactor-spaces",
     "migrationhub-config",
     "migrationhubstrategy",
     "mobile",
@@ -717,6 +722,7 @@ ServiceName = Literal[
     "qldb-session",
     "quicksight",
     "ram",
+    "rbin",
     "rds",
     "rds-data",
     "redshift",
@@ -732,6 +738,7 @@ ServiceName = Literal[
     "route53-recovery-readiness",
     "route53domains",
     "route53resolver",
+    "rum",
     "s3",
     "s3control",
     "s3outposts",
